@@ -38,7 +38,6 @@ try:
 except ImportError:
     np = None
 
-from . import PY3
 
 time_types = (dt.date, dt.datetime, pywintypes.TimeType)
 if np:
@@ -51,7 +50,7 @@ BOOK_CALLER = None
 missing = object()
 
 
-class COMRetryMethodWrapper(object):
+class COMRetryMethodWrapper:
 
     def __init__(self, method):
         self.__method = method
@@ -87,7 +86,7 @@ class ExcelBusyError(Exception):
         super(ExcelBusyError, self).__init__("Excel application is not responding")
 
 
-class COMRetryObjectWrapper(object):
+class COMRetryObjectWrapper:
     def __init__(self, inner):
         object.__setattr__(self, '_inner', inner)
 
@@ -264,7 +263,7 @@ def is_range_instance(xl_range):
     # return pyid.GetTypeInfo().GetDocumentation(-1)[0] == 'Range'
 
 
-class Apps(object):
+class Apps:
     def keys(self):
         k = []
         for hwnd in get_excel_hwnds():
@@ -286,7 +285,7 @@ class Apps(object):
         raise KeyError('Could not find an Excel instance with this PID.')
 
 
-class App(object):
+class App:
 
     def __init__(self, spec=None, add_book=True, xl=None):
         if spec is not None:
@@ -414,7 +413,7 @@ class App(object):
         return self.xl.Run(macro, *args)
 
 
-class Books(object):
+class Books:
 
     def __init__(self, xl):
         self.xl = xl
@@ -456,7 +455,7 @@ class Books(object):
             yield Book(xl=xl)
 
 
-class Book(object):
+class Book:
 
     def __init__(self, xl):
         self.xl = xl
@@ -515,7 +514,7 @@ class Book(object):
         self.xl.Activate()
 
 
-class Sheets(object):
+class Sheets:
     def __init__(self, xl):
         self.xl = xl
 
@@ -556,7 +555,7 @@ class Sheets(object):
             return Sheet(xl=self.xl.Add())
 
 
-class Sheet(object):
+class Sheet:
 
     def __init__(self, xl):
         self.xl = xl
@@ -665,7 +664,7 @@ class Sheet(object):
         return Range(xl=self.xl.UsedRange)
 
 
-class Range(object):
+class Range:
 
     def __init__(self, xl):
         if isinstance(xl, tuple):
@@ -1028,17 +1027,11 @@ def _com_time_to_datetime(com_time, datetime_builder):
 
     """
 
-    if PY3:
-        # The py3 version of pywintypes has its time type inherit from datetime.
-        # We copy to a new datetime so that the returned type is the same between 2/3
-        # Changed: We make the datetime object timezone naive as Excel doesn't provide info
-        return datetime_builder(month=com_time.month, day=com_time.day, year=com_time.year,
-                                hour=com_time.hour, minute=com_time.minute, second=com_time.second,
-                                microsecond=com_time.microsecond, tzinfo=None)
-    else:
-        assert com_time.msec == 0, "fractional seconds not yet handled"
-        return datetime_builder(month=com_time.month, day=com_time.day, year=com_time.year,
-                                hour=com_time.hour, minute=com_time.minute, second=com_time.second)
+    # Pywintypes has its time type inherit from datetime.
+    # Changed: We make the datetime object timezone naive as Excel doesn't provide info
+    return datetime_builder(month=com_time.month, day=com_time.day, year=com_time.year,
+                            hour=com_time.hour, minute=com_time.minute, second=com_time.second,
+                            microsecond=com_time.microsecond, tzinfo=None)
 
 
 def _datetime_to_com_time(dt_time):
@@ -1068,24 +1061,20 @@ def _datetime_to_com_time(dt_time):
         dt_time = dt.datetime(dt_time.year, dt_time.month, dt_time.day,
                               tzinfo=win32timezone.TimeZoneInfo.utc())
 
-    if PY3:
-        # The py3 version of pywintypes has its time type inherit from datetime.
-        # For some reason, though it accepts plain datetimes, they must have a timezone set.
-        # See http://docs.activestate.com/activepython/2.7/pywin32/html/win32/help/py3k.html
-        # We replace no timezone -> UTC to allow round-trips in the naive case
-        if pd and isinstance(dt_time, pd.Timestamp):
-            # Otherwise pandas prints ignored exceptions on Python 3
-            dt_time = dt_time.to_pydatetime()
-        # We don't use pytz.utc to get rid of additional dependency
-        # Don't do any timezone transformation: simply cutoff the tz info
-        # If we don't reset it first, it gets transformed into UTC before transferred to Excel
-        dt_time = dt_time.replace(tzinfo=None)
-        dt_time = dt_time.replace(tzinfo=win32timezone.TimeZoneInfo.utc())
+    # pywintypes has its time type inherit from datetime.
+    # For some reason, though it accepts plain datetimes, they must have a timezone set.
+    # See http://docs.activestate.com/activepython/2.7/pywin32/html/win32/help/py3k.html
+    # We replace no timezone -> UTC to allow round-trips in the naive case
+    if pd and isinstance(dt_time, pd.Timestamp):
+        # Otherwise pandas prints ignored exceptions on Python 3
+        dt_time = dt_time.to_pydatetime()
+    # We don't use pytz.utc to get rid of additional dependency
+    # Don't do any timezone transformation: simply cutoff the tz info
+    # If we don't reset it first, it gets transformed into UTC before transferred to Excel
+    dt_time = dt_time.replace(tzinfo=None)
+    dt_time = dt_time.replace(tzinfo=win32timezone.TimeZoneInfo.utc())
 
-        return dt_time
-    else:
-        assert dt_time.microsecond == 0, "fractional seconds not yet handled"
-        return pywintypes.Time(dt_time.timetuple())
+    return dt_time
 
 
 def prepare_xl_data_element(x):
@@ -1106,7 +1095,7 @@ def open_template(fullpath):
     os.startfile(fullpath)
 
 
-class Shape(object):
+class Shape:
 
     def __init__(self, xl):
         self.xl = xl
@@ -1174,7 +1163,7 @@ class Shape(object):
         self.xl.Activate()
 
 
-class Collection(object):
+class Collection:
 
     def __init__(self, xl):
         self.xl = xl
@@ -1209,7 +1198,7 @@ class Shapes(Collection):
     _wrap = Shape
 
 
-class Chart(object):
+class Chart:
 
     def __init__(self, xl_obj=None, xl=None):
         self.xl = xl_obj.Chart if xl is None else xl
@@ -1315,7 +1304,7 @@ class Charts(Collection):
         ))
 
 
-class Picture(object):
+class Picture:
 
     def __init__(self, xl):
         self.xl = xl
@@ -1392,7 +1381,7 @@ class Pictures(Collection):
         ).DrawingObject)
 
 
-class Names(object):
+class Names:
     def __init__(self, xl):
         self.xl = xl
 
@@ -1420,7 +1409,7 @@ class Names(object):
         return Name(xl=self.xl.Add(name, refers_to))
 
 
-class Name(object):
+class Name:
     def __init__(self, xl):
         self.xl = xl
 
